# Sample GraphQL Queries
Get started with the GraphQL API using example queries and mutations.
In this section, you can find sample queries and mutations for the SAP LeanIX GraphQL API. You can try them out in the [GraphiQL Tool](https://help.sap.com/docs/leanix/ea/graphql-api?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a6d497a4410149a8bffcc34da11b9__graphiql_tool) in your workspace.
To learn more about GraphQL queries and mutations, see [GraphQL Basics](https://help.sap.com/docs/leanix/ea/graphql-basics?locale=en-US&state=PRODUCTION&version=CLOUD "Learn the GraphQL basics. Create and execute your first queries and mutations.").
